# mididoctor
## Stand-alone, comprehensive and easy-to-use MIDI check and repair Python package

![MIDI-Doctor-Artwork](https://github.com/user-attachments/assets/a8532b66-6b8a-4d17-86a2-d300165e5be2)

***

## With just one line of code, MIDI Doctor will check and heal

* MIDI signature
* MIDI channels range
* MIDI pitches range
* MIDI velocities range
* MIDI patch changes range
* Duplicate pitches
* Bad chords
* Excessively short durations
* Excessively long durations
* Overlapping durations
* Text events inconsistencies
* Excessively quiet dynamics

***

## Install

```sh
pip install mididoctor
```

***

## Basic use example

```python
import mididoctor

mididoctor.heal_midi('Come To My Window.mid')
```

***

### Project Los Angeles
### Tegridy Code 2025
